===============================================================
EXPOsan: EXPOsition of sanitation and resource recovery systems
===============================================================

.. image:: https://img.shields.io/pypi/l/exposan?color=blue&logo=UIUC&style=flat
   :target: https://github.com/QSD-Group/EXPOsan/blob/main/LICENSE.txt
.. image:: https://img.shields.io/pypi/pyversions/exposan?style=flat
   :target: https://pypi.python.org/pypi/exposan
.. image:: https://img.shields.io/pypi/v/exposan?style=flat&color=blue
   :target: https://pypi.org/project/exposan/


What is ``EXPOsan``?
--------------------
The ``EXPOsan`` package contains systems developed using the `QSDsan <https://github.com/QSD-Group/QSDsan>`_ package. Please refer to the individual README files within each system module for loading instructions and exemplary results.


Installation
------------
The package can be downloaded from `PyPI <https://pypi.org/project/exposan/>`_.

If you use pip:

.. code:: bash

    pip install exposan


To get the git version (use the depth flag to choose how many commit histories you want to clone):

.. code:: bash

    git clone https://github.com/QSD-Group/EXPOsan.git --depth=1


Authors and Contributing
------------------------
``EXPOsan`` is developed by the Quantitative Sustainable Design Group led by members of the `Guest Group <http://engineeringforsustainability.com/>`_ and `other developers <https://github.com/QSD-Group/EXPOsan/graphs/contributors>`_ that have contributed to the repository. Yalin Li (@yalinli2; `email <zoe.yalin.li@gmail.com>`_) is the currently maintainer of this repository and package.

Please refer to the `Contributing to QSDsan <https://qsdsan.readthedocs.io/en/latest/CONTRIBUTING.html>`_ section of the documentation for instructions and guidelines.


License information
-------------------
Please refer to the ``LICENSE.txt`` for information on the terms & conditions for usage of this software, and a DISCLAIMER OF ALL WARRANTIES.